cmd

package
v0.0.0-...-249e40d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Overview

Package cmd contains CLI command definitions

Index

Constants

This section is empty.

Variables

var (
	// Logger is xatu-cbt global logger instance.
	Logger *logrus.Logger
)

Functions

func Execute

func Execute()

Execute runs the root command.

func InitLogger

func InitLogger()

InitLogger initializes or reinitializes the logger based on environment variables.

Types

This section is empty.

Directories

Path Synopsis
Package main is the entry point for the xatu-cbt application
Package main is the entry point for the xatu-cbt application

Jump to